<?php
    /**
     * Created by PhpStorm.
     * User: stes
     * Date: 31.05.18
     * Time: 14:30
     */
    
    namespace backend\controllers;
    
    use artbox\core\admin\actions\Create;
    use artbox\core\admin\actions\Delete;
    use artbox\core\admin\actions\Index;
    use artbox\core\admin\actions\Update;
    use artbox\core\admin\actions\View;
    use artbox\core\admin\interfaces\ControllerInterface;
    use artbox\core\admin\widgets\Form;
    use common\models\Doctor;
    use yii\filters\AccessControl;
    use yii\filters\VerbFilter;
    use yii\web\Controller;
    use yii\web\NotFoundHttpException;

    class DoctorController extends Controller implements ControllerInterface
    {
        public function behaviors()
        {
            return [
                'verbs'  => [
                    'class'   => VerbFilter::className(),
                    'actions' => [
                        'delete' => [ 'POST' ],
                    ],
                ],
                'access' => [
                    'class' => AccessControl::className(),
                    'rules' => [
                        [
                            'allow' => true,
                            'roles' => [ '@' ],
                        ],
                    ],
                ],
            ];
        }
    
        public function actions()
        {
            return [
                'index'  => [
                    'class'            => Index::className(),
                    'columns'          => [
                        'name'      => [
                            'type' => Index::ACTION_COL,
                        ],
                        
                        'position' => [
                            'type' => Index::STRING_COL,
                        ],
                        'sort'       => [
                            'type' => Index::POSITION_COL,
                        ],
                        'status'    => [
                            'type' => Index::STATUS_COL,
                        ],
                    ],
                    'model'            => Doctor::className(),
                    'hasLanguage'      => true,
                    'enableMassDelete' => true,
                    'modelPrimaryKey'  => 'id',
                ],
                'create' => array_merge([ 'class' => Create::className() ], self::fieldsConfig()),
                'update' => array_merge([ 'class' => Update::className() ], self::fieldsConfig()),
                'view'   => [
                    'class'          => View::className(),
                    'model'          => Doctor::className(),
                    'hasAlias'       => true,
                    'languageFields' => [
                        [
                            'name' => 'name',
                            'type' => Form::STRING,
                        ],
                        [
                            'name' => 'position',
                            'type' => Form::STRING,
                        ],
                        [
                            'name' => 'description',
                            'type' => Form::WYSIWYG,
                        ],
                    ],
                    'fields'         => [
                        [
                            'name'              => 'service_id',
                            'type'              => Form::RELATION,
                            'relationAttribute' => 'title',
                            'relationName'      => 'service',
                            'multiple'          => false,
                        ],
                    ],
                ],
                'delete' => [
                    'class' => Delete::className(),
                ],
            ];
        }
    
        public function findModel($id)
        {
            $model = Doctor::find()
                            ->with('languages')
                            ->where([ 'id' => $id ])
                            ->one();
            if ($model !== null) {
                return $model;
            } else {
                throw new NotFoundHttpException('The requested page does not exist.');
            }
        }
    
        public function newModel()
        {
            return new Doctor();
        }
    
        public function deleteModel($id)
        {
            $page = Doctor::find()
                           ->with('languages.alias')
                           ->where(
                               [
                                   'id' => $id,
                               ]
                           )
                           ->one();
            $langs = call_user_func(
                [
                    $page,
                    'getVariationModels',
                ]
            );
            foreach ($langs as $lang) {
                if ($lang->alias !== null) {
                    $lang->alias->delete();
                }
            }
        
            return $page->delete();
        }
    
        protected static function fieldsConfig()
        {

	        return [
                'model'          => Doctor::className(),
                'hasAlias'       => true,

		        'languageFields' => [

			        [
                        'name' => 'name',
                        'type' => Form::STRING,
                        'decorate' => true
                    ],
                    [
                        'name' => 'description',
                        'type' => Form::WYSIWYG,
                    ],
                    [
                        'name' => 'position',
                        'type' => Form::STRING,
                    ],
                ],
                'fields'         => [

                    [
                        'name' => 'image_id',
                        'type' => Form::IMAGE
                    ],
                    [
                        'name'              => 'service_id',
                        'type'              => Form::RELATION,
                        'relationAttribute' => 'title',
                        'relationName'      => 'service',
                        'multiple'          => false,
                    ],
                    [
                        'name' => 'status',
                        'type' => Form::BOOL,
                    ],
	                [
		                'name' => 'sort',
		                'type' => Form::NUMBER,
	                ],

                ],
            ];
        }
        
    }