<?php
    /**
     * Created by PhpStorm.
     * User: stes
     * Date: 22.05.18
     * Time: 14:44
     */
    
    namespace backend\controllers;
    
    use artbox\core\admin\actions\Create;
    use artbox\core\admin\actions\Delete;
    use artbox\core\admin\actions\Index;
    use artbox\core\admin\actions\Update;
    use artbox\core\admin\actions\View;
    use artbox\core\admin\interfaces\ControllerInterface;
    use artbox\core\admin\widgets\Form;
    use common\models\Service;
    use yii\filters\AccessControl;
    use yii\filters\VerbFilter;
    use yii\helpers\Url;
    use yii\web\Controller;
    use yii\web\JsExpression;
    use yii\web\NotFoundHttpException;
    
    class ServiceController extends Controller implements ControllerInterface
    {
        public function behaviors()
        {
            return [
                'verbs'  => [
                    'class'   => VerbFilter::className(),
                    'actions' => [
                        'delete' => [ 'POST' ],
                    ],
                ],
                'access' => [
                    'class' => AccessControl::className(),
                    'rules' => [
                        [
                            'allow' => true,
                            'roles' => [ '@' ],
                        ],
                    ],
                ],
            ];
        }
        
        public function actions()
        {
            return [
                'index'  => [
                    'class'            => Index::className(),
                    'columns'          => [
                        'title'      => [
                            'type' => Index::ACTION_COL,
                        ],
                        'parent'     => [
                            'type'         => Index::RELATION_COL,
                            'columnConfig' => [
                                'relationField' => 'title',
                            ],
                        ],
                        'updated_at' => [
                            'type' => Index::DATETIME_COL,
                        ],
                        'sort'       => [
                            'type' => Index::POSITION_COL,
                        ],
                        'status'     => [
                            'type' => Index::STATUS_COL,
                        ],
                    ],
                    'model'            => Service::className(),
                    'hasLanguage'      => true,
                    'enableMassDelete' => true,
                    'modelPrimaryKey'  => 'id',
                ],
                'create' => array_merge([ 'class' => Create::className() ], self::fieldsConfig()),
                'update' => array_merge([ 'class' => Update::className() ], self::fieldsConfig()),
                'view'   => [
                    'class'          => View::className(),
                    'model'          => Service::className(),
                    'hasAlias'       => true,
                    'languageFields' => [
                        [
                            'name' => 'title',
                            'type' => Form::STRING,
                        ],
                        [
                            'name' => 'body',
                            'type' => Form::WYSIWYG,
                        ],
                    ],
                    'fields'         => [
                        [
                            'name'              => 'parent_id',
                            'type'              => Form::RELATION,
                            'relationAttribute' => 'title',
                            'relationName'      => 'parent',
                            'multiple'          => false,
                        ],
                    ],
                ],
                'delete' => [
                    'class' => Delete::className(),
                ],
            ];
        }
        
        public function findModel($id)
        {
            $model = Service::find()
                            ->with('languages')
                            ->where([ 'id' => $id ])
                            ->one();
            if ($model !== null) {
                return $model;
            } else {
                throw new NotFoundHttpException('The requested page does not exist.');
            }
        }
        
        public function newModel()
        {
            return new Service();
        }
        
        public function deleteModel($id)
        {
            $page = Service::find()
                           ->with('languages.alias')
                           ->where(
                               [
                                   'id' => $id,
                               ]
                           )
                           ->one();
            $langs = call_user_func(
                [
                    $page,
                    'getVariationModels',
                ]
            );
            foreach ($langs as $lang) {
                if ($lang->alias !== null) {
                    $lang->alias->delete();
                }
            }
            
            return $page->delete();
        }
        
        protected static function fieldsConfig()
        {
            return [
                'tinyMceConfig'  => [
                    'language'      => 'ru',
                    'clientOptions' => [
                        'file_browser_callback' => new JsExpression(
                            "function(field_name, url, type, win) {
window.open('" . Url::to(
                                [
                                    'imagemanager/manager',
                                    'view-mode'   => 'iframe',
                                    'select-type' => 'tinymce',
                                ]
                            ) . "&tag_name='+field_name,'','width=800,height=540 ,toolbar=no,status=no,menubar=no,scrollbars=no,resizable=no');
}"
                        ),
                        'plugins'               => [
                            "advlist autolink lists link charmap print preview anchor",
                            "searchreplace visualblocks code fullscreen",
                            "insertdatetime media table contextmenu paste image",
                        ],
                        'toolbar'               => "undo redo | styleselect | bold italic | alignleft aligncenter alignright alignjustify | bullist numlist outdent indent | link image | code | prices | button",
                        'setup' => new JsExpression('function (editor) {
                                editor.addButton("prices", {
                                                          text: "Цена",
                                                          icon: false,
                                                          onclick: function () {
                                                            editor.insertContent("[[prices]]");
                                                          }
                                                        });
                                                         editor.addButton("button", {
                                                          text: "Записаться на прием",
                                                          icon: false,
                                                          onclick: function () {
                                                            editor.insertContent("[[button]]");
                                                          }
                                                        });
                        }')
                        ],
                ],
                'model'          => Service::className(),
                'hasAlias'       => true,
                'languageFields' => [
                    [
                        'name'     => 'title',
                        'type'     => Form::STRING,
                        'decorate' => true,
                    ],
                    [
                        'name' => 'body',
                        'type' => Form::WYSIWYG,
                    ],
                ],
                'fields'         => [
                    [
                        'name' => 'image_id',
                        'type' => Form::IMAGE,
                    ],
                    [
                        'name'              => 'parent_id',
                        'type'              => Form::RELATION,
                        'relationAttribute' => 'title',
                        'relationName'      => 'parent',
                        'multiple'          => false,
                    ],
                    [
                        'name' => 'status',
                        'type' => Form::BOOL,
                    ],
                    [
                        'name' => 'sort',
                        'type' => Form::NUMBER,
                    ],
                ],
            ];
        }
    }