<?php

namespace common\models;

use artbox\core\models\Image;
use artbox\core\models\Language;
use backend\traits\AliasableTrait;
use Yii;
use yii\db\ActiveQuery;
use yii\helpers\Json;
use yii2tech\ar\position\PositionBehavior;
use yii2tech\ar\variation\VariationBehavior;

/**
 * This is the model class for table "doctor".
 *
 * @property int $id
 * @property int $service_id
 * @property bool $status
 * @property int $sort
 *
 * @property Service $service
 * @property DoctorLang[] $doctorLangs
 * @property Language[] $languages
 * * from VariationBehavior
 * @method ActiveQuery  hasDefaultVariationRelation();
 */
class Doctor extends \yii\db\ActiveRecord
{
    use AliasableTrait;
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'doctor';
    }
    public function behaviors()
    {
        return [
            'translations'         => [
                'class'                             => VariationBehavior::className(),
                'variationsRelation'                => 'languages',
                'defaultVariationRelation'          => 'language',
                'variationOptionReferenceAttribute' => 'language_id',
                'optionModelClass'                  => Language::className(),
                'defaultVariationOptionReference'   => function () {
                    return Language::getCurrent()->id;
                },
                'optionQueryFilter'                 => function (ActiveQuery $query) {
                    $query->where(
                        [
                            'status' => true,
                        ]
                    );
                },
            ],
//            'positionBehavior'     => [
//                'class'             => PositionBehavior::className(),
//                'positionAttribute' => 'sort',
//            ],
        ];
    }
    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['service_id', 'sort'], 'default', 'value' => null],
	        [['service_id', 'sort', 'image_id'], 'integer'],
            [['status'], 'boolean'],
            [['service_id'], 'exist', 'skipOnError' => true, 'targetClass' => Service::className(), 'targetAttribute' => ['service_id' => 'id']],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('app', 'ID'),
            'service_id' => Yii::t('app', 'Service ID'),
            'status' => Yii::t('app', 'Status'),
            'sort' => Yii::t('app', 'Sort'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getService()
    {
        return $this->hasOne(Service::className(), ['id' => 'service_id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getLanguages()
    {
        return $this->hasMany(DoctorLang::className(), ['doctor_id' => 'id']);
    }
    
    public function getLanguage(){
        return $this->hasDefaultVariationRelation();
    }
    
    /**
     * @return string
     */
    public function getRoute()
    {
        return Json::encode(
            [
                'doctor/view',
                'id' => $this->id,
            ]
        );
    }
    
    public function getImage(){
        return $this->hasOne(Image::className(), ['id' => 'image_id']);
    }
}
