<?php

namespace common\models;

use artbox\core\models\Alias;
use artbox\core\models\Language;
use Yii;

/**
 * This is the model class for table "doctor_lang".
 *
 * @property int $language_id
 * @property int $alias_id
 * @property int $doctor_id
 * @property string $name
 * @property string $position
 * @property string $description
 *
 * @property Alias $alias
 * @property Doctor $doctor
 * @property Language $language
 */
class DoctorLang extends \yii\db\ActiveRecord
{
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'doctor_lang';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['language_id', 'alias_id', 'doctor_id'], 'default', 'value' => null],
            [['language_id', 'alias_id', 'doctor_id'], 'integer'],
            [['description'], 'string'],
            [['name', 'position'], 'string', 'max' => 255],
            [['language_id', 'doctor_id'], 'unique', 'targetAttribute' => ['language_id', 'doctor_id']],
            [['alias_id'], 'exist', 'skipOnError' => true, 'targetClass' => Alias::className(), 'targetAttribute' => ['alias_id' => 'id']],
            [['doctor_id'], 'exist', 'skipOnError' => true, 'targetClass' => Doctor::className(), 'targetAttribute' => ['doctor_id' => 'id']],
            [['language_id'], 'exist', 'skipOnError' => true, 'targetClass' => Language::className(), 'targetAttribute' => ['language_id' => 'id']],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'language_id' => Yii::t('app', 'Language ID'),
            'alias_id' => Yii::t('app', 'Alias ID'),
            'doctor_id' => Yii::t('app', 'Doctor ID'),
            'name' => Yii::t('app', 'Name'),
            'position' => Yii::t('app', 'Position'),
            'description' => Yii::t('app', 'Description'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getAlias()
    {
        return $this->hasOne(Alias::className(), ['id' => 'alias_id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getDoctor()
    {
        return $this->hasOne(Doctor::className(), ['id' => 'doctor_id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getLanguage()
    {
        return $this->hasOne(Language::className(), ['id' => 'language_id']);
    }
}
