<?php

namespace common\models;

use artbox\core\models\Image;
use backend\traits\AliasableTrait;
use Yii;
use artbox\core\models\Language;
use yii\behaviors\TimestampBehavior;
use yii\db\ActiveQuery;
use yii\db\ActiveRecord;
use yii\helpers\Json;
use yii2tech\ar\position\PositionBehavior;
use yii2tech\ar\variation\VariationBehavior;

/**
 * This is the model class for table "package".
 *
 * @property int $id
 * @property int $parent_id
 * @property int $sort
 * @property bool $status
 * @property int $level
 * @property int $created_at
 * @property int $updated_at
 *
 * @property PackageLang[] $serviceLangs
 * @property Language[] $languages
 * from VariationBehavior
 * @method ActiveQuery  hasDefaultVariationRelation();
 */
class Package extends ActiveRecord
{
    use AliasableTrait;
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'package';
    }
    
    /**
     * @return array
     */
    public function behaviors()
    {
        return [
            'translations'         => [
                'class'                             => VariationBehavior::className(),
                'variationsRelation'                => 'languages',
                'defaultVariationRelation'          => 'language',
                'variationOptionReferenceAttribute' => 'language_id',
                'optionModelClass'                  => Language::className(),
                'defaultVariationOptionReference'   => function () {
                    return Language::getCurrent()->id;
                },
                'optionQueryFilter'                 => function (ActiveQuery $query) {
                    $query->where(
                        [
                            'status' => true,
                        ]
                    );
                },
            ],
            'positionBehavior'     => [
                'class'             => PositionBehavior::className(),
                'positionAttribute' => 'sort',
            ],
            'timestamp'            => [
                'class' => TimestampBehavior::className(),
            ],
        ];
    }
    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['sort', 'created_at', 'updated_at'], 'default', 'value' => null],
            [['sort', 'created_at', 'updated_at', 'image_id', 'service_id'], 'integer'],
            [['status'], 'boolean'],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('app', 'ID'),
            'sort' => Yii::t('app', 'Sort'),
            'status' => Yii::t('app', 'Status'),
            'created_at' => Yii::t('app', 'Created At'),
            'updated_at' => Yii::t('app', 'Updated At'),
            'image_id' => Yii::t('app', 'Image'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getLanguages()
    {
        return $this->hasMany(PackageLang::className(), ['package_id' => 'id']);
    }
    
    
    
    public function getLanguage(){
        return $this->hasDefaultVariationRelation();
    }
    
    /**
     * @return string
     */
    public function getRoute()
    {
        return Json::encode(
            [
                'package/view',
                'id' => $this->id,
            ]
        );
    }
    
    public function getImage(){
        return $this->hasOne(Image::className(), ['id' => 'image_id']);
    }
    
    public function getService(){
        return $this->hasOne(Service::className(), ['id' => 'service_id']);
    }
    
}
