<?php

namespace common\models;

use artbox\core\models\Language;
use Yii;
use yii\db\ActiveQuery;
use yii2tech\ar\position\PositionBehavior;
use yii2tech\ar\variation\VariationBehavior;

/**
 * This is the model class for table "price".
 *
 * @property int $id
 * @property int $service_id
 * @property int $price
 * @property int $status
 * @property int $sort
 *
 * @property Service $service
 * @property PriceLang[] $priceLangs
 * @property \artbox\core\models\Language[] $languages
 * * from VariationBehavior
 * @method ActiveQuery  hasDefaultVariationRelation();
 */
class Price extends \yii\db\ActiveRecord
{
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'price';
    }
    public function behaviors()
    {
        return [
            'translations'         => [
                'class'                             => VariationBehavior::className(),
                'variationsRelation'                => 'languages',
                'defaultVariationRelation'          => 'language',
                'variationOptionReferenceAttribute' => 'language_id',
                'optionModelClass'                  => Language::className(),
                'defaultVariationOptionReference'   => function () {
                    return Language::getCurrent()->id;
                },
                'optionQueryFilter'                 => function (ActiveQuery $query) {
                    $query->where(
                        [
                            'status' => true,
                        ]
                    );
                },
            ],
            'positionBehavior'     => [
                'class'             => PositionBehavior::className(),
                'positionAttribute' => 'sort',
            ],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['service_id', 'price', 'status', 'sort'], 'default', 'value' => null],
            [['service_id', 'price', 'status', 'sort'], 'integer'],
            [['service_id'], 'exist', 'skipOnError' => true, 'targetClass' => Service::className(), 'targetAttribute' => ['service_id' => 'id']],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('app', 'ID'),
            'service_id' => Yii::t('app', 'Service ID'),
            'price' => Yii::t('app', 'Price'),
            'status' => Yii::t('app', 'Status'),
            'sort' => Yii::t('app', 'Sort'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getService()
    {
        return $this->hasOne(Service::className(), ['id' => 'service_id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getLanguages()
    {
        return $this->hasMany(PriceLang::className(), ['price_id' => 'id']);
    }
    
    public function getLanguage(){
        return $this->hasDefaultVariationRelation();
    }
}
